from cvAR.Utils import stackImages, cornerRect, findContours,\
    overlayPNG, rotateImage, putTextRect
from cvAR.ColorModule import ColorFinder
from cvAR.FPS import FPS
from cvAR.PIDModule import PID
from cvAR.PlotModule import LivePlot
from cvAR.FaceDetectionModule import FaceDetector
from cvAR.HandTrackingModule import HandDetector
from cvAR.ClassificationModule import Classifier
from cvAR.FaceMeshModule import FaceMeshDetector
from cvAR.PoseModule import PoseDetector
from cvAR.SerialModule import SerialObject
from cvAR.SelfiSegmentationModule import SelfiSegmentation


import pathlib
from setuptools import setup

# The directory containing this file
HERE = pathlib.Path(__file__).parent

# The text of the README file
README = (HERE / "README.md").read_text()

# This call to setup() does all the work
setup(
    name="cvAR",
    version="0.1",
    description=" a package use to built AR projects",
    long_description=README,
    long_description_content_type="text/markdown",
    url="https://github.com/uditvashisht/saral-square",
    author="E L E V E N",
    author_email="meetp3249@gmail.com",
    Keywords=['AugumentedReality','HandTracking','FaceTracking','PoseEstimation'],
    license="MIT",
    classifiers=[
        'Development Status :: 3 - Alpha',
        'Intended Audience :: Developers',
        'Topic :: Software Development :: Build Tools',
        "License :: OSI Approved :: MIT License",
        "Programming Language :: Python :: 3.7",
        "Programming Language :: Python :: 3.8",
        "Programming Language :: Python :: 3.9",
    ],
    packages=["cvAR"],
    include_package_data=True,
    install_requires=[],

)
